import Foundation

/**
 This struct holds metadata about a file resource that is stored in the content folder.
 */
struct FileResourceFile {

    /// The file/image description in German
    let englishDescription: String?

    /// The file/image description in English
    let germanDescription: String?

    /// The list of generated image versions for this image
    let generatedImages: [String]?

    /// A custom file path in the output folder where this file is located
    let customOutputPath: String?

    /// A version string of this resource, mostly for assets
    let version: String?

    /// A URL where the resource was copied/downloaded from
    let sourceUrl: String?

    /// The date when the file was added
    let addedDate: Date

    /// The date when the file was last modified
    let modifiedDate: Date
}


extension FileResourceFile: Codable {

}
